@@ -1,7 +1,7 @@
 package Spreadsheet::HTML;
 use strict;
 use warnings FATAL => 'all';
-our $VERSION = '0.33';
+our $VERSION = '0.34';
 
 use Exporter 'import';
 our @EXPORT_OK = qw(
@@ -113,20 +113,18 @@ sub _process {
         return wantarray ? ( data => $self->{data}, %{ $args || {} } ) : $data;
     }
 
-    # headings is an alias for -row0
-    $args->{-row0} = delete $args->{headings} if exists $args->{headings};
+    # headings is an alias for -r0
+    $args->{-r0} = delete $args->{headings} if exists $args->{headings};
 
-    # headings to index mapping for -colX
+    # headings to index mapping (alias for some -cX)
     my %index = ();
     if ($#{ $data->[0] }) {
-        %index = map { '-' . $data->[0][$_] || '' => $_ } 0 .. $#{ $data->[0] };
+        %index = map { '-' . ($data->[0][$_] || '') => $_ } 0 .. $#{ $data->[0] };
         for (grep /^-/, keys %$args) {
-            $args->{"-col$index{$_}" } = delete $args->{$_} if exists $index{$_};
+            $args->{"-c$index{$_}" } = delete $args->{$_} if exists $index{$_};
         }
     }
 
-    my $empty = exists $args->{empty} ? $args->{empty} : '&nbsp;';
-
     for my $row (0 .. $args->{_max_rows} - 1) {
 
         unless ($args->{_layout}) {
@@ -136,37 +134,29 @@ sub _process {
 
         for my $col (0 .. $#{ $data->[$row] }) {
             my $tag = (!$row and !($args->{headless} or $args->{matrix})) ? 'th' : 'td';
-            my ( $cdata, $attr ) = _expand_code_or_hash( $args->{$tag}, $data->[$row][$col] );
-            $args->{$tag} = [ $args->{$tag} ] unless ref( $args->{$tag} ) eq 'ARRAY';
 
-            # -colX
-            if (exists $args->{"-col$col"}) {
+            my ( $cdata, $attr ) = ( $data->[$row][$col], undef );
+            for ($tag, "-c$col", "-r$row", "-r${row}c${col}") {
+                next unless exists $args->{$_};
                 my $new_attr;
-                ( $cdata, $new_attr ) = _expand_code_or_hash( $args->{"-col$col"}, $cdata );
+                $args->{$_} = [ $args->{$_} ] unless ref( $args->{$_} ) eq 'ARRAY';
+                for (@{ $args->{$_} }) {
+                    if (ref($_) eq 'CODE') {
+                        $cdata = $_->($cdata);
+                    } elsif (ref($_) eq 'HASH') {
+                        $new_attr = $_;
+                    }
+                }
                 $attr = { %{ $attr || {} }, %{ $new_attr || {} } };
             }
 
-            # -rowX (overides -colX)
-            if (exists $args->{"-row$row"}) {
-                my $new_attr;
-                ( $cdata, $new_attr ) = _expand_code_or_hash( $args->{"-row$row"}, $cdata );
-                $attr = { %{ $attr || {} }, %{ $new_attr || {} } };
-            }
-
-            # -rowXcolX (overides -rowX)
-            if (exists $args->{"-row${row}col${col}"}) {
-                my $new_attr;
-                ( $cdata, $new_attr ) = _expand_code_or_hash( $args->{"-row${row}col${col}"}, $cdata );
-                $attr = { %{ $attr || {} }, %{ $new_attr || {} } };
-            }
-
-            # handle empty
+            my $empty = exists $args->{empty} ? $args->{empty} : '&nbsp;';
             do{ no warnings; $cdata =~ s/^\s*$/$empty/g };
 
             $data->[$row][$col] = { 
                 tag => $tag, 
                 (defined( $cdata ) ? (cdata => $cdata) : ()), 
-                (defined( $attr )  ? (attr => $attr)   : ()),
+                (keys( %$attr )    ? (attr => $attr)   : ()),
             };
         }
     }
@@ -287,35 +277,28 @@ sub _args {
     $data = Spreadsheet::HTML::File::Loader::parse( $args->{file} ) if $args->{file};
     $data = [ $data ] unless ref($data);
     $data = [ $data ] unless ref($data->[0]);
-    $data = [ [undef] ] if !scalar @{ $data->[0] };
+
+    if ($args->{wrap} and defined $data->[0][0]) {
+        my @flat = map @$_, @$data;
+        $data = [
+            map [ @flat[$_ .. $_ + $args->{wrap} - 1] ],
+            _range( 0, $#flat, $args->{wrap} )
+        ];
+    }
+
+    $args->{_max_rows} = scalar @{ $data }      || 1;
+    $args->{_max_cols} = scalar @{ $data->[0] } || 1;
 
     my %fill;
     if ($args->{fill}) {
-        ($fill{row},$fill{col}) = $args->{fill} =~ /^(\d+)\D(\d+)$/;
+        ($fill{row},$fill{col}) = split /\D/, $args->{fill};
+        $args->{_max_rows} = $fill{row} if (int($fill{row} || 0)) > ($args->{_max_rows});
+        $args->{_max_cols} = $fill{col} if (int($fill{col} || 0)) > ($args->{_max_cols});
     }
 
-    $args->{_max_rows} = scalar @{ $data };
-    $args->{_max_cols} = scalar @{ $data->[0] };
-    $args->{_max_rows} = $fill{row} if ($fill{row} || 0) > ($args->{max_rows} || 0);
-    $args->{_max_cols} = $fill{col} if ($fill{col} || 0) > ($args->{max_cols} || 0);
-
     return ( $self, Clone::clone($data), $args );
 }
 
-sub _expand_code_or_hash {
-    my ( $thingy, $cdata ) = @_;
-    my $attr;
-    $thingy = [ $thingy ] unless ref( $thingy ) eq 'ARRAY';
-    for (@{ $thingy }) {
-        if (ref($_) eq 'CODE') {
-            $cdata = $_->($cdata);
-        } elsif (ref($_) eq 'HASH') {
-            $attr = $_;
-        }
-    }
-    return ( $cdata, $attr );
-}
-
 sub _range {grep!(($_-$_[0])%($_[2]||1)),$_[0]..$_[1]}
 
 
@@ -441,7 +424,7 @@ with little to no additional coding.
 
 =item * C<checkerboard( colors, %params )>
 
-=item * C<animate( direction, x, y, jquery, %params )>
+=item * C<animate( fgdirection, bgdirection, jquery, %params )>
 
 =item * C<banner( on, off, text, font, %params )>
 
@@ -496,6 +479,15 @@ cells (currently only pads the right and bottom sides.)
 
   fill => '5x12'
 
+=item * C<wrap>
+
+Can be supplied in conjunction with a 1D C<data> to
+automatically wrap into a 2D array matrix. Can also
+"rewrap" existed 2D array matrices, but at the expense
+of likely mangling the headings.
+
+  wrap => 10 
+
 =item * C<theta: 0, 90, 180, 270, -90, -180, -270>
 
 Rotates table clockwise for positive values and 
@@ -573,7 +565,7 @@ only td tags, no th tags.
 =item * C<headless: 0 or 1>
 
 Render the table with without the headings row at all. 
-The first row after the headings is still C<-row1>, thus
+The first row after the headings is still C<-r1>, thus
 any reference to C<headings> will be discarded too.
 
 =item * C<headings>
@@ -591,7 +583,7 @@ Or both:
   headings => [ sub { uc shift }, { class => "foo" } ]
 
 Since C<headings> is a natural alias for the dynamic parameter
-C<-row0>, it could be considered as a dynamic parameter. Be
+C<-r0>, it could be considered as a dynamic parameter. Be
 careful not to prepend a dash to C<headings> ... only dynamic
 parameters use leading dashes.
 
@@ -606,35 +598,35 @@ leading dashes to seperate them from literal and tag parameters.
 
 =over 4
 
-=item * C<-rowX>
+=item * C<-rX>
 
 Apply this callback subroutine to the entire row X.
 (0 index based)
 
-  -row3 => sub { uc shift }
+  -r3 => sub { uc shift }
 
 Or apply hash ref as attributes:
 
-  -row3 => { class => 'some-class' }
+  -r3 => { class => 'some-class' }
 
 Or both:
 
-  -row3 => [ sub { uc shift }, { class => "foo" } ]
+  -r3 => [ sub { uc shift }, { class => "foo" } ]
 
-=item * C<-colX>
+=item * C<-cX>
 
 Apply this callback to the entire column X.
 (0 index based)
 
-  -col4 => sub { sprintf "%02d", shift || 0 }
+  -c4 => sub { sprintf "%02d", shift || 0 }
 
 Or apply hash ref as attributes:
 
-  -col4 => { class => 'some-class' }
+  -c4 => { class => 'some-class' }
 
 Or both:
 
-  -col4 => [ sub { uc shift }, { class => "foo" } ]
+  -c4 => [ sub { uc shift }, { class => "foo" } ]
 
 You can alias any column number by the value of the heading
 name in that column:
@@ -645,11 +637,13 @@ name in that column:
 
   -employee_no => [ sub { sprintf "%08d", shift }, { class => "foo" } ]
 
-=item * C<-rowXcolX>
+=item * C<-rXcX>
 
 Apply this callback or hash ref of attributres
 to the cell at row X and column X. (0 index based)
 
+  -r3c4 => { class => 'special-cell' }
+
 =back
 
 =head2 TAG PARAMETERS
