@@ -52,6 +52,7 @@ sub checkerboard {
         matrix   => 1,
         headings => sub { join(' ', map { sprintf '<b>%s</b>', ucfirst(lc($_)) } split ('_', shift || '')) },
         @_,
+        wrap => 0,
         td => { %{ $args->{td} || {} }, style  => { 'background-color' => $colors } },
     );
 
@@ -63,13 +64,14 @@ sub animate {
     $self = shift if ref($_[0]) =~ /^Spreadsheet::HTML/;
     ($self,$data,$args) = $self ? $self->_args( @_ ) : Spreadsheet::HTML::_args( @_ );
 
-    $args->{direction} ||= 'right';
-    $args->{interval}  ||= 200;
+    $args->{fgdirection} ||= ($args->{bgdirection} || $args->{bx} || $args->{by}) ? '' : 'right';
+    $args->{bgdirection} ||= '';
+    $args->{interval}    ||= 200;
 
     my @cells;
     for my $r ( 0 .. $args->{_max_rows} - 1 ) {
         for my $c ( 0 .. $args->{_max_cols} - 1 ) {
-            my $cell = sprintf '-row%scol%s', $r, $c;
+            my $cell = sprintf '-r%sc%s', $r, $c;
             push @cells, $cell => {
                 id     => join( '-', $r, $c ),
                 class  => 'animate',
@@ -84,7 +86,7 @@ sub animate {
     );
 
     my $js = Spreadsheet::HTML::Presets::Animate::_javascript( %$args );
-    delete $args->{$_} for qw( direction x y interval jquery );
+    delete $args->{$_} for qw( fgdirection bgdirection fx fy bx by interval jquery );
 
     return( $js, @args ) if $args->{animate};
 
@@ -115,7 +117,7 @@ sub banner {
             for my $row (0 .. $#banner) {
                 my @line = split //, $banner[$row];
                 for my $col (0 .. $#line) {
-                    my $key = sprintf '-row%scol%s', $row, $col;
+                    my $key = sprintf '-r%sc%s', $row, $col;
                     if ($args->{emboss}) {
                         if ($line[$col] eq ' ') {
                             push @cells, ( $key => { style => { 'background-color' => $off } } );
@@ -138,6 +140,7 @@ sub banner {
     my @args = (
         @_,
         @cells,
+        wrap => 0,
     );
 
     my $table = $self ? $self->generate( @args ) : Spreadsheet::HTML::generate( @args );
@@ -153,29 +156,25 @@ sub maze {
     my @cells = ();
     unless ($NO_LISTUTIL) {
 
-        my $height = 20;
-        my $width  = 16;
-        if ($args->{fill}) {
-            ($height,$width) = $args->{fill} =~ /^(\d+)\D(\d+)$/;
-            delete $args->{fill};
-        }
-        push @cells, ( fill => "${height}x${width}" );
+        my $rows = $args->{_max_rows} == 1 ? 20 : $args->{_max_rows};
+        my $cols = $args->{_max_cols} == 1 ? 16 : $args->{_max_cols};
+        my $off  = $args->{off}    || 'white';
+        my $on   = $args->{on}     || 'black';
 
-        my $off    = $args->{off}    || 'white';
-        my $on     = $args->{on}     || 'black';
+        push @cells, ( fill => "${rows}x${cols}" );
 
         my (@grid,@stack);
-        for my $h (0 .. $height - 1) {
+        for my $h (0 .. $rows - 1) {
             $grid[$h] = [ map {
                 x     => $_, y => $h,
                 walls => [1,1,1,1], # W S E N
-            }, 0 .. $width - 1 ];
+            }, 0 .. $cols - 1 ];
         }
 
         my %neighbor = ( 0 => 2, 1 => 3, 2 => 0, 3 => 1 );
         my $visited = 1;
-        my $curr = $grid[rand $height][rand $width];
-        while ($visited < $height * $width) {
+        my $curr = $grid[rand $rows][rand $cols];
+        while ($visited < $rows * $cols) {
             my @neighbors;
             for (
                 [ 3, $grid[ $curr->{y} - 1 ][ $curr->{x} ] ], # north
@@ -206,7 +205,7 @@ sub maze {
 
         for my $row (0 .. $#grid) {
             for my $col (0 .. @{ $grid[$row] }) {
-                my $key = sprintf '-row%scol%s', $row, $col;
+                my $key = sprintf '-r%sc%s', $row, $col;
                 my %style = ( 'background-color' => $off );
                 for (0 .. $#{ $grid[$row][$col]{walls} } ) {
                     $style{$style_map{$_}} = "2px solid $on" if $grid[$row][$col]{walls}[$_]; 
@@ -272,8 +271,8 @@ sub calculator {
         },
         caption     => qq(<input id="display" style="background-color: #F1FACA; height: 8%; width: 80%; text-align: right; $attrs" />),
         td          => [ { %attrs }, sub { qq(<button style="width: 100%; height: 100%; $attrs">$_[0]</button>) } ],
-        -row3col3   => { rowspan => 2, %attrs },
-        -row4col0   => { colspan => 2, %attrs },
+        -r3c3       => { rowspan => 2, %attrs },
+        -r4c0       => { colspan => 2, %attrs },
         _layout     => 1,
         data        => $data,
         theta       => 0,
@@ -281,6 +280,7 @@ sub calculator {
         tgroups     => 0,
         headless    => 0,
         pinhead     => 0,
+        wrap        => 0,
         matrix      => 1,
     );
 
@@ -305,7 +305,7 @@ sub conway {
     my @cells;
     for my $r ( 0 .. $args->{_max_rows} - 1 ) {
         for my $c ( 0 .. $args->{_max_cols} - 1 ) {
-            my $cell = sprintf '-row%scol%s', $r, $c;
+            my $cell = sprintf '-r%sc%s', $r, $c;
             push @cells,
                 $cell => {
                     id     => join( '-', $r, $c ),
@@ -335,7 +335,7 @@ sub calendar {
     $self = shift if ref($_[0]) =~ /^Spreadsheet::HTML/;
     ($self,$data,$args) = $self ? $self->_args( @_ ) : Spreadsheet::HTML::_args( @_ );
 
-    my @args;
+    my @cal_args;
     unless ($NO_TIMEPIECE) {
         my $time = Time::Piece->strptime(
             join( '-', 
@@ -351,10 +351,17 @@ sub calendar {
             1 .. $last
         );
         
-        push @args, [
-            map [ @flat[$_ .. $_ + 6] ],
-            Spreadsheet::HTML::_range( 0, $#flat, 7 )
-        ];
+        push @cal_args, ( data => \@flat );
+
+        my %day_args = map {($_ => $args->{$_})} grep /^-\d+$/, keys %$args;
+        for (keys %day_args) {
+            my $day = abs($_);
+            next if $day > $last;
+            my $index = $day + $first + 5;
+            my $row = int($index / 7);
+            my $col = $index % 7;
+            push @cal_args, ( sprintf( '-r%sc%s', $row, $col ) => $day_args{$_} );
+        }
 
         my $caption = join( ' ', $time->fullmonth, $time->year );
         if ($args->{animate}) {
@@ -366,10 +373,17 @@ sub calendar {
             ($attr) = values %{ $args->{caption} };
         }
 
-        push @args, ( caption => { $caption => $attr } );
+        push @cal_args, ( caption => { $caption => $attr } );
     }
 
-    unshift @args, @_; 
+    my @args = (
+        @cal_args,
+        @_,
+        wrap    => 7,
+        theta   => 0,
+        flip    => 0,
+        matrix  => 0,
+    );        
 
     return $self ? $self->generate( @args ) : Spreadsheet::HTML::generate( @args );
 }
@@ -409,6 +423,7 @@ sub checkers {
         headless => 0,
         pinhead  => 0,
         matrix   => 1,
+        wrap     => 0,
         fill     => '8x8',
         data     => \@data,
     );
@@ -449,6 +464,7 @@ sub chess {
         headless => 0,
         pinhead  => 0,
         matrix   => 1,
+        wrap     => 0,
         fill     => '8x8',
         data     => \@data,
     );
@@ -515,7 +531,7 @@ my $tmpl = '
         for my $col (0 .. $#chars) {
             next unless my $color = $map{ $chars[$col] };
             push @cells, ( 
-                "-row${row}col${col}" => {
+                "-r${row}c${col}" => {
                     width  => 16,
                     height => 8,
                     style  => { 'background-color' => $color },
@@ -529,6 +545,7 @@ my $tmpl = '
         tgroups  => 0,
         headless => 0,
         matrix   => 1,
+        wrap     => 0,
         fill     => join( 'x', $total_rows, $total_cols ),
         @cells,
         @_,
@@ -576,7 +593,7 @@ my $tmpl = '
         for my $col (0 .. $#chars) {
             next unless my $color = $map{ $chars[$col] };
             push @cells, ( 
-                "-row${row}col${col}" => {
+                "-r${row}c${col}" => {
                     width  => 16,
                     height => 8,
                     style  => { 'background-color' => $color },
@@ -590,6 +607,7 @@ my $tmpl = '
         tgroups  => 0,
         headless => 0,
         matrix   => 1,
+        wrap     => 0,
         fill     => join( 'x', $total_rows, $total_cols ),
         @cells,
         @_,
@@ -659,17 +677,19 @@ Attempts to form diagonal patterns by adding an extra color
 if need be. C<colors> default to red and green and C<extra>
 defaults to white.
 
-=item * C<animate( direction, interval, jquery, %params )>
+=item * C<animate( fgdirection, bgdirection, interval, jquery, %params )>
 
-Moves the contents of each cell in the direction specified.
+Moves the contents (C<fg*> for CDATA, C<bg*> for
+attributes) of each cell in the direction specified.
 Valid values are C<up>, C<down>, C<left> and C<right>.
 
 Set the timer with C<interval> (defaults to 200 miliseconds).
 
-  animate( direction => 'right', interval => 300 )
+  animate( fgdirection => 'right', interval => 300 )
 
-Can optionally use C<x> and/or C<y> instead of C<direction>
-to specify which axis(es) to animate.
+Can optionally use C<fx> and/or C<fy> instead of C<fgdirection>
+to specify which axis(es) to animate. (Ditto for C<bx> and
+C<by> for C<bgdirection>.
 
 Uses Google's jQuery API unless you specify another URI via
 the C<jquery> param. Javascript will be minified
@@ -723,6 +743,14 @@ Generates a static calendar. Defaults to current month and year.
 
   calendar( month => 7, year, 2015 )
 
+Mark a day of the month like so:
+
+  calendar( month => 12, -25 => { bgcolor => 'red' } )
+
+Default rules still apply to styling columns by any heading:
+
+  calendar( -Tue => { class => 'ruby' } )
+
 =item * C<maze( on, off, fill, %params )>
 
 Generates a static maze.
